@@ -60,7 +60,7 @@ sub values_for {
 
 sub to_xml {
     my $self = shift;
-    my $gen  = XML::Generator->new( ':std' );
+    my $gen  = XML::Generator->new( ':std', escape => 'always,even-entities' );
     my %attr = ( $self->boost ? ( boost => $self->boost ) : () );
 
     return $gen->doc( \%attr, map { $_->to_xml } $self->fields );
